@@ -1,15 +1,8 @@
-from trame.app import get_app_instance
-from trame.dev import main
+from trame.internal import (
+  change, Controller, flush_state, get_cli_parser, get_state, get_version,
+  is_dirty, is_dirty_all, port, start, State, stop, trigger, update_state
+)
 from trame.layouts import update_layout
-from trame.server import port, start, stop
-from trame.state import (
-    change, flush_state, get_state, is_dirty, is_dirty_all, State, update_state
-)
-from trame.trigger import Controller, trigger, trigger_key
-from trame.utils import (
-    get_cli_parser, get_version, log_js_error, print_server_info,
-    validate_key_names
-)
 
 __version__ = get_version()
 
@@ -30,6 +23,12 @@ As are these setters:
 passed, and ``update_state()`` should be used instead to specify additional
 arguments (e.g. ``force=True``).
 
+The state may also be accessed and updated similar to dictionaries:
+
+>>> value = state["field"]
+>>> state["field"] = value
+>>> state.update({"field": value})
+
 This object may be imported via
 
 >>> from trame import state
@@ -56,28 +55,31 @@ callbacks when conditions in the application change.
 
 __all__ = [
     # Order these how we want them to show up in the docs
+
+    # Server-related
     "start",
     "stop",
     "port",
+
+    # State-related
     "state",
     "update_state",
     "get_state",
-    "update_layout",
-    "get_cli_parser",
     "flush_state",
     "is_dirty",
     "is_dirty_all",
     "change",
+
+    # Trigger-related
     "trigger",
     "controller",
 
+    # Layout-related
+    "update_layout",
+
+    # CLI-related
+    "get_cli_parser",
+
     # These are not exposed in the docs
     "__version__",
-    "get_app_instance",
-    "get_version",
-    "log_js_error",
-    "main",
-    "print_server_info",
-    "trigger_key",
-    "validate_key_names",
 ]
