@@ -165,8 +165,9 @@ class VtkRemoteLocalView(AbstractElement):
     The VtkRemoteLocalView component is a blend of VtkLocalView and VtkRemoteView where the user can choose dynamically which mode they want to be in. When instantiating a VtkRemoteLocalView several variables and triggers will be created for you to more easily control your view.
 
     >>> rl_view = vtk.VtkRemoteLocalView(
-    ...   view=...,                # Instance of vtkRenderWindow (required)
-    ...
+    ...   view=...,                # Instance of the view (required)
+    ...                            # - VTK: vtkRenderWindow
+    ...                            # - Paraview: viewProxy
     ...   # Just VtkRemoteLocalView params
     ...   namespace=...,           # Prefix for variables and triggers. See below. (required)
     ...   mode="local",            # Decide between local or remote. See below.
@@ -264,7 +265,9 @@ class VtkRemoteView(AbstractElement):
     The VtkRemoteView component relies on the server for rendering by sending images to the client by binding your vtkRenderWindow to it. This component gives you control over the image size and quality to reduce latency while interacting.
 
     >>> remote_view = vtk.vtkRemoteView(
-    ...   view=...,               # Instance of vtkRenderWindow (required)
+    ...   view=...,               # Instance of the view (required)
+    ...                           # - VTK: vtkRenderWindow
+    ...                           # - Paraview: viewProxy
     ...   ref=...,                # Identifier for this component
     ...   interactive_quality=60, # [0, 100] 0 for fastest render, 100 for best quality
     ...   interactive_ratio=...,  # [0.1, 1] Image size scale factor while interacting
@@ -320,16 +323,18 @@ class VtkLocalView(AbstractElement):
         The VtkLocalView component relies on the server for defining the vtkRenderWindow but then only the geometry is exchanged with the client. The server does not need a GPU as no rendering is happening on the server. The vtkRenderWindow is only used to retrieve the scene data and parameters (coloring by, representations, ...). By relying on the same vtkRenderWindow, you can easily switch from a ``VtkRemoteView`` to a ``VtkLocalView`` or vice-versa. This component gives you controls on how you want to map mouse interaction with the camera. The default setting mimic default VTK interactor style so you will rarely have to override to the ``interactor_settings``.
 
     >>> local_view = vtk.VtkLocalView(
-    >>>   view=...,                # Instance of vtkRenderWindow (required)
-    >>>   ref=...,                 # Identifier for this component
-    >>>   context_name=...,        # Namespace for geometry cache
-    >>>   interactor_settings=..., # Options for camera controls. See below.
-    >>>   interactor_events=(      # Enable vtk.js interactor events for method binding
-    >>>     "events",
-    >>>     ['EndAnimation'],
-    >>>    ),
-    >>>    EndAnimation=end,       # Bind method to the enabled event
-    >>> )
+    ...   view=...,                # Instance of the view (required)
+    ...                            # - VTK: vtkRenderWindow
+    ...                            # - Paraview: viewProxy
+    ...   ref=...,                 # Identifier for this component
+    ...   context_name=...,        # Namespace for geometry cache
+    ...   interactor_settings=..., # Options for camera controls. See below.
+    ...   interactor_events=(      # Enable vtk.js interactor events for method binding
+    ...     "events",
+    ...     ['EndAnimation'],
+    ...    ),
+    ...    EndAnimation=end,       # Bind method to the enabled event
+    ... )
     """
 
     def __init__(self, view, ref="view", **kwargs):
